@@ -5,19 +5,19 @@
                                             sep=','
                                             ) # read.csv2
                                             
-   write.csv.R2X <- function (x,R2X,pfad='data/R2X/')
-                                                write.csv(
-                                                R2X[[x]] ,
-                                                file = pfad %&% x %&% '.csv',
-                                                row.names=FALSE
-                                                ) # write.csv
-                                            
+   write.csv.R2X <- function (x,G,pfad='data/R2X/')
+                                            write.csv(
+                                            G$.R2X[[x]],
+                                            file = pfad %&% x %&% '.csv',
+                                            row.names=FALSE
+                                            ) # read.csv2
+
 
 
 
 #                                            write.table(
-#                                            G$R2X[[x]],
+#                                            G$.R2X[[x]],
 #                                            file = pfad %&% x %&% '.txt',
 #                                            row.names=FALSE,
 #                                            sep=','
-#                                            ) # write.csv2
+#                                            ) # write.csv2
\ No newline at end of file
